@@ -13,7 +13,7 @@ class PeertubeCommand(PlayCommand):
 
     syntax = "{ricerca}"
 
-    async def get_url(self, args):
+    async def get_urls(self, args):
         search = urllib.parse.quote(args.joined(require_at_least=1))
         async with aiohttp.ClientSession() as session:
             async with session.get(self.config["Peertube"]["instance_url"] +
@@ -21,4 +21,4 @@ class PeertubeCommand(PlayCommand):
                 j = await response.json()
         if j["total"] < 1:
             raise InvalidInputError("Nessun video trovato.")
-        return f'{self.config["Peertube"]["instance_url"]}/videos/watch/{j["data"][0]["uuid"]}'
+        return [f'{self.config["Peertube"]["instance_url"]}/videos/watch/{j["data"][0]["uuid"]}']
