@@ -10,11 +10,13 @@ class RageCommand(Command):
 
     description: str = "Arrabbiati per qualcosa, come una software house californiana."
 
-    _MAD = ["MADDEN MADDEN MADDEN MADDEN",
-           "EA bad, praise Geraldo!",
-           "Stai sfogando la tua ira sul bot!",
-           "Basta, io cambio gilda!",
-           "Fondiamo la RRYG!"]
+    _MAD = [
+        "MADDEN MADDEN MADDEN MADDEN",
+        "EA bad, praise Geraldo!",
+        "Stai sfogando la tua ira sul bot!",
+        "Basta, io cambio gilda!",
+        "Fondiamo la RRYG!"
+    ]
 
     async def run(self, args: CommandArgs, data: CommandData) -> None:
         await data.reply(f"😠 {random.sample(self._MAD, 1)[0]}")
